Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( // GitCommit is the git commit SHA GitCommit = "unknown" // GitDescribe is the output of git describe --tags --dirty GitDescribe = "unknown" // BuildDate is the date when the binary was built BuildDate = "unknown" // GoVersion is the Go version used to build the binary GoVersion = runtime.Version() // Platform is the OS/Architecture combination Platform = fmt.Sprintf("%s/%s", runtime.GOOS, runtime.GOARCH) )
Build information that will be set via ldflags during build
Functions ¶
func GetFormattedBuildInfo ¶
func GetFormattedBuildInfo() string
GetFormattedBuildInfo returns formatted build information for logging
Types ¶
Click to show internal directories.
Click to hide internal directories.